/*
** Copyright (c) 2008-2017 The Khronos Group Inc.
**
** Licensed under the Apache License, Version 2.0 (the "License");
** you may not use this file except in compliance with the License.
** You may obtain a copy of the License at
**
**     http://www.apache.org/licenses/LICENSE-2.0
**
** Unless required by applicable law or agreed to in writing, software
** distributed under the License is distributed on an "AS IS" BASIS,
** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
** See the License for the specific language governing permissions and
** limitations under the License.
*/

/*
 * Skeleton egl.h to provide compatibility for early GLES 1.0
 * applications. Several early implementations included gl.h
 * in egl.h leading applications to include only egl.h
 */

#ifndef __legacy_egl_h_
#define __legacy_egl_h_

#include <EGL/egl.h>
#include <GLES/gl.h>

#endif /* __legacy_egl_h_ */
